@@ -83,7 +83,7 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 {
   ClutterActor *marker;
   ClutterActor *layer_actor;
-  ClutterColor city_color = { 0xf3, 0x94, 0x07, 0xbb };
+  ClutterColor city_color = { 0x36, 0x89, 0xe6, 0xbb };
   ClutterColor text_color = { 0xff, 0xff, 0xff, 0xff };
   LocationCallbackData callback_data;
   gchar *station = NULL;
